module Mks
  module Maintenance
    class CostTypesController < ApplicationController
      before_action :set_cost_type, only: %i[show update]
      def index
        render json: Mks::Common::MethodResponse.success_response(CostType.all)
      end

      def show
        render json: Mks::Common::MethodResponse.success_response(@cost_type)
      end

      def create
        params = cost_type_params
        params[:fields] = JSON(params[:fields])
        cost_type = CostType.new(params)
        if cost_type.save
          response = Mks::Common::MethodResponse.success_response(cost_type, 'Cost type saved successfully!')
          render json: response, status: :created, location: cost_type
        else
          response = Mks::Common::MethodResponse.failure_response(cost_type)
          render json: response, status: :unprocessable_entity
        end
      end

      def update
        params = cost_type_params
        params[:fields] = JSON(params[:fields]) if params[:fields]

        if @cost_type.update(params)
          response = Mks::Common::MethodResponse.success_response(@cost_type, 'Cost type updated successfully!')
          render json: response
        else
          render json: Mks::Common::MethodResponse.failure_response(@cost_type), status: :unprocessable_entity
        end
      end


      private

      def set_cost_type
        @cost_type = CostType.find(params[:id])
      end

      def cost_type_params
        params.require(:cost_type).permit(:code, :name, :fields)
      end
    end
  end
end