module Mks
  module Maintenance
    class JobCardsController < ApplicationController
      before_action :set_job_card, only: %i[show update checkout checkin]

      def index
        data = JobCard.where(prepared_by_id: current_user_id)
        render json: Mks::Common::MethodResponse.success_response(data)
      end

      def checkouts
        data = JobCard.where(checkout_by_id: current_user_id)
        render json: Mks::Common::MethodResponse.success_response(data)
      end

      def checkins
        data = JobCard.where(checkin_by_id: current_user_id)
        render json: Mks::Common::MethodResponse.success_response(data)
      end

      def show
        render json: @job_card
      end

      def create
        job_card = JobCard.new(job_card_params)
        job_card.prepared_by = current_user

        if job_card.save
          response = Mks::Common::MethodResponse.success_response(job_card, 'Job card created successfully!')
          render json: response, status: :created, location: job_card
        else
          response = Mks::Common::MethodResponse.failure_response(job_card)
          render json: response, status: :unprocessable_entity
        end
      end

      def update
        job_card_update(@job_card, job_card_params)
      end

      def checkout
        job_card_update(@job_card, checkout_params)
      end

      def checkin
        job_card_update(@job_card, checkin_params)
      end

      private

      def job_card_update(job_card, params)
        if job_card.update(params)
          response = Mks::Common::MethodResponse.success_response(job_card, 'Job card updated successfully!')
          render json: response
        else
          render json: Mks::Common::MethodResponse.failure_response(job_card), status: :unprocessable_entity
        end
      end

      def set_job_card
        @job_card = JobCard.find(params[:id])
      end

      def job_card_params
        params.require(:job_card).permit(:code, :maintenance_service_order_id, :start_date, :due_date,
                                         :service_provider_id, :checkout_by_id, :checkout_date, :checkout_to_id,
                                         :checkin_by_id, :checkin_date, :checkin_to_id, :approved, :checkout_confirmed,
                                         :checkin_confirmed, :costs_approved)
      end

      def checkout_params
        params.require(:checkout).permit(:checkout_by_id, :checkout_date, :checkout_to_id)
      end

      def checkin_params
        params.require(:checkin).permit(:checkin_by_id, :checkin_date, :checkin_to_id)
      end
    end
  end
end