module Mks
  module Maintenance
    class MaintenanceServiceOrdersController < ApplicationController
      before_action :set_maintenance_service_order, only: [:update]
      def index
        data = MaintenanceServiceOrder.all
        render json: Mks::Common::MethodResponse.success_response(data)
      end

      def create
        mso = MaintenanceServiceOrder.new(maintenance_service_order_params)
        if mso.save
          res = Mks::Common::MethodResponse.success_response(
            mso,
            'Maintenance services order saved successfully !'
          )
          render json: res
        else
          res = Mks::Common::MethodResponse.failure_response(mso)
          render json: res, status: :unprocessable_entity
        end
      end

      def update
        if @mso.update(maintenance_service_order_params)
          res = Mks::Common::MethodResponse.success_response(
            @mso,
            'Maintenance services order updated successfully !'
          )
          render json: res
        else
          res = Mks::Common::MethodResponse.failure_response(@mso)
          render json: res, status: :unprocessable_entity
        end
      end

      def filter
        fu = FilterUtil.new
        data = fu.get_filtered_data(filter_params[:type], filter_params[:filters])
        res = Mks::Common::MethodResponse.success_response(data, '')
        render json: res
      end

      private

      def maintenance_service_order_params
        params.require(:maintenance_service_order).permit(:id, :title, :description, :equipment_item_id, :status,
                                                          :maintenance_type_id, :prepared_by_id, :approved_by_id,
                                                          :start_date, :end_date, :remark, :current_reading, :approved)
      end

      def set_maintenance_service_order
        @mso = MaintenanceServiceOrder.find(params[:id])
      end

      def filter_params
        params.permit(:type, filters:[:key, :value, :cond])
      end

    end
  end
end